@@ -26,7 +26,17 @@ from braket.aws.aws_session import AwsSession
 from braket.circuits.circuit import Circuit
 from braket.circuits.circuit_helpers import validate_circuit_and_shots
 from braket.device_schema import GateModelParameters
-from braket.device_schema.dwave import DwaveDeviceParameters
+from braket.device_schema.dwave import (
+    Dwave2000QDeviceParameters,
+    DwaveAdvantageDeviceParameters,
+    DwaveDeviceParameters,
+)
+from braket.device_schema.dwave.dwave_2000Q_device_level_parameters_v1 import (
+    Dwave2000QDeviceLevelParameters,
+)
+from braket.device_schema.dwave.dwave_advantage_device_level_parameters_v1 import (
+    DwaveAdvantageDeviceLevelParameters,
+)
 from braket.device_schema.ionq import IonqDeviceParameters
 from braket.device_schema.rigetti import RigettiDeviceParameters
 from braket.device_schema.simulators import GateModelSimulatorDeviceParameters
@@ -251,7 +261,7 @@ class AwsQuantumTask(QuantumTask):
     def _update_status_if_nonterminal(self):
         # If metadata has not been populated, the first call to _status will fetch it,
         # so the second _status call will no longer need to
-        metadata_absent = self._metadata is None
+        metadata_absent = not self._metadata
         cached = self._status(True)
         return cached if cached in self.TERMINAL_STATES else self._status(metadata_absent)
 
@@ -270,8 +280,12 @@ class AwsQuantumTask(QuantumTask):
             if the task completed successfully; returns `None` if the task did not complete
             successfully or the future timed out.
         """
-        if self._result or self._status(True) in self.NO_RESULT_TERMINAL_STATES:
+        if self._result or (
+            self._metadata and self._status(True) in self.NO_RESULT_TERMINAL_STATES
+        ):
             return self._result
+        if self._metadata and self._status(True) in self.RESULTS_READY_STATES:
+            return self._download_result()
         try:
             async_result = self.async_result()
             return async_result.get_loop().run_until_complete(async_result)
@@ -287,9 +301,7 @@ class AwsQuantumTask(QuantumTask):
             self._logger.debug(e)
             self._logger.info("No event loop found; creating new event loop")
             asyncio.set_event_loop(asyncio.new_event_loop())
-        if not hasattr(self, "_future"):
-            self._future = asyncio.get_event_loop().run_until_complete(self._create_future())
-        elif (
+        if not hasattr(self, "_future") or (
             self._future.done()
             and not self._future.cancelled()
             and self._result is None
@@ -339,15 +351,9 @@ class AwsQuantumTask(QuantumTask):
         while (time.time() - start_time) < self._poll_timeout_seconds:
             # Used cached metadata if cached status is terminal
             task_status = self._update_status_if_nonterminal()
-            current_metadata = self.metadata(True)
             self._logger.debug(f"Task {self._arn}: task status {task_status}")
             if task_status in AwsQuantumTask.RESULTS_READY_STATES:
-                result_string = self._aws_session.retrieve_s3_object_body(
-                    current_metadata["outputS3Bucket"],
-                    current_metadata["outputS3Directory"] + f"/{AwsQuantumTask.RESULTS_FILENAME}",
-                )
-                self._result = _format_result(BraketSchemaBase.parse_raw_schema(result_string))
-                return self._result
+                return self._download_result()
             elif task_status in AwsQuantumTask.NO_RESULT_TERMINAL_STATES:
                 self._result = None
                 return None
@@ -364,8 +370,17 @@ class AwsQuantumTask(QuantumTask):
         self._result = None
         return None
 
+    def _download_result(self):
+        current_metadata = self.metadata(True)
+        result_string = self._aws_session.retrieve_s3_object_body(
+            current_metadata["outputS3Bucket"],
+            current_metadata["outputS3Directory"] + f"/{AwsQuantumTask.RESULTS_FILENAME}",
+        )
+        self._result = _format_result(BraketSchemaBase.parse_raw_schema(result_string))
+        return self._result
+
     def __repr__(self) -> str:
-        return f"AwsQuantumTask('id':{self.id})"
+        return f"AwsQuantumTask('id/taskArn':'{self.id}')"
 
     def __eq__(self, other) -> bool:
         if isinstance(other, AwsQuantumTask):
@@ -430,15 +445,21 @@ def _(
     aws_session: AwsSession,
     create_task_kwargs: Dict[str, Any],
     device_arn: str,
-    device_parameters: Union[dict, DwaveDeviceParameters],
+    device_parameters: Union[
+        dict,
+        DwaveDeviceParameters,
+        DwaveAdvantageDeviceParameters,
+        Dwave2000QDeviceParameters,
+    ],
     disable_qubit_rewiring,
     *args,
     **kwargs,
 ) -> AwsQuantumTask:
+    device_params = _create_annealing_device_params(device_parameters, device_arn)
     create_task_kwargs.update(
         {
             "action": problem.to_ir().json(),
-            "deviceParameters": DwaveDeviceParameters.parse_obj(device_parameters).json(),
+            "deviceParameters": device_params.json(exclude_none=True),
         }
     )
 
@@ -446,6 +467,35 @@ def _(
     return AwsQuantumTask(task_arn, aws_session, *args, **kwargs)
 
 
+def _create_annealing_device_params(device_params, device_arn):
+    if type(device_params) is not dict:
+        device_params = device_params.dict()
+
+    # check for device level or provider level parameters
+    device_level_parameters = device_params.get("deviceLevelParameters", None) or device_params.get(
+        "providerLevelParameters", {}
+    )
+
+    # deleting since it may be the old version
+    if "braketSchemaHeader" in device_level_parameters:
+        del device_level_parameters["braketSchemaHeader"]
+
+    if "Advantage" in device_arn:
+        device_level_parameters = DwaveAdvantageDeviceLevelParameters.parse_obj(
+            device_level_parameters
+        )
+        return DwaveAdvantageDeviceParameters(deviceLevelParameters=device_level_parameters)
+    elif "2000Q" in device_arn:
+        device_level_parameters = Dwave2000QDeviceLevelParameters.parse_obj(device_level_parameters)
+        return Dwave2000QDeviceParameters(deviceLevelParameters=device_level_parameters)
+    else:
+        raise Exception(
+            f"Amazon Braket could not find a device with ARN: {device_arn}. "
+            "To continue, make sure that the value of the device_arn parameter "
+            "corresponds to a valid QPU."
+        )
+
+
 def _create_common_params(
     device_arn: str, s3_destination_folder: AwsSession.S3DestinationFolder, shots: int
 ) -> Dict[str, Any]:
